import { PackageJson } from 'type-fest';
/**
 * Determines whether or not the package has a given dependency
 * @param  {object} packageJsonData  Valid JSON
 * @param  {string} nodeName         Name of a node in the package.json file
 * @param  {string} depsToCheckFor   An array of packages to check for
 * @return {boolean}                 True if the package has a dependency. False if it is not or the node is missing.
 */
export declare const hasDependency: (packageJsonData: PackageJson | any, nodeName: string, depsToCheckFor: string[]) => boolean;
/**
 * Determines whether or not the package has a pre-release version of a given dependency
 * @param  {object} packageJsonData         Valid JSON
 * @param  {string} nodeName                Name of a node in the package.json file
 * @param  {string} depsToCheckFor          An array of packages to check for
 * @return {boolean}                        True if the package has a pre-release version of a dependency. False if it is not or the node is missing.
 */
export declare const hasDepPrereleaseVers: (packageJsonData: PackageJson | any, nodeName: string, depsToCheckFor: string[]) => boolean;
/**
 * Determines whether or not the package has a dependency with a major version of 0
 * @param  {object} packageJsonData   Valid JSON
 * @param  {string} nodeName          Name of a node in the package.json file
 * @param  {object} config            Rule configuration
 * @return {boolean}                  True if the package has a dependency with version 0. False if it does not or the node is missing.
 */
export declare const hasDepVersZero: (packageJsonData: PackageJson | any, nodeName: string, config: any) => boolean;
/**
 * Determines if the dependencies version string starts with the specified range
 * @param  {String}   dependencyVersion   Dependency's version range
 * @param  {String}   rangeSpecifier      A version range specifier
 * @return {Boolean}                      True if the version starts with the range, false if it doesn't.
 */
export declare const doesVersStartsWithRange: (dependencyVersion: string, rangeSpecifier: string) => boolean;
/**
 * Determines whether or not all dependency version ranges match expected range
 * @param  {object} packageJsonData  Valid JSON
 * @param  {string} nodeName         Name of a node in the package.json file
 * @param  {string} rangeSpecifier   A version range specifier
 * @param  {object} config           Rule configuration
 * @return {boolean}                 False if the package has an invalid range. True if it is not or the node is missing.
 */
export declare const areVersRangesValid: (packageJsonData: PackageJson | any, nodeName: string, rangeSpecifier: string, config: any) => boolean;
/**
 * Determines if any dependencies have a version string that starts with the specified invalid range
 * @param  {object} packageJsonData  Valid JSON
 * @param  {string} nodeName         Name of a node in the package.json file
 * @param  {string} rangeSpecifier   A version range specifier
 * @param  {object} config           Rule configuration
 * @return {Boolean}                 True if any dependencies versions start with the invalid range, false if they don't.
 */
export declare const doVersContainInvalidRange: (packageJsonData: PackageJson | any, nodeName: string, rangeSpecifier: string, config: any) => boolean;
export interface AbsoluteVersionCheckerResult {
    onlyAbsoluteVersionDetected: boolean;
    dependenciesChecked: number;
}
/**
 * Determines whether or not all dependency versions are absolut
 * @param {object} packageJsonData    Valid JSON
 * @param {string} nodeName           Name of a node in the package.json file
 * @param {object} config             Rule configuration
 * @return {boolean}                  False if the package has an non-absolute version. True if it is not or the node is missing.
 */
export declare const areVersionsAbsolute: (packageJsonData: PackageJson | any, nodeName: string, config: any) => boolean;
/**
 * Determines whether or not all dependency versions are absolut
 * @param {object} packageJsonData    Valid JSON
 * @param {string} nodeName           Name of a node in the package.json file
 * @param {object} config             Rule configuration
 * @return {boolean}                  False if the package has an non-absolute version. True if it is not or the node is missing.
 */
export declare const doVersContainNonAbsolute: (packageJsonData: PackageJson | any, nodeName: string, config: any) => boolean;
/**
 * Determines whether or not dependency versions are git repository
 * @param {object} packageJsonData    Valid JSON
 * @param {string} nodeName           Name of a node in the package.json file
 * @param {object} config             Rule configuration
 * @return {boolean}                  True if the package has an git repo.
 */
export declare const doVersContainGitRepository: (packageJsonData: PackageJson | any, nodeName: string, config: any) => boolean;
/**
 * Determines whether or not dependency versions contains archive url
 * @param {object} packageJsonData    Valid JSON
 * @param {string} nodeName           Name of a node in the package.json file
 * @param {object} config             Rule configuration
 * @return {boolean}                  True if the package contain archive url.
 */
export declare const doVersContainArchiveUrl: (packageJsonData: PackageJson | any, nodeName: string, config: any) => boolean;
/**
 * Determines whether or not dependency versions contains file url
 * @param {object} packageJsonData    Valid JSON
 * @param {string} nodeName           Name of a node in the package.json file
 * @param {object} config             Rule configuration
 * @return {boolean}                  True if the package contain file url.
 */
export declare const doVersContainFileUrl: (packageJsonData: PackageJson | any, nodeName: string, config: any) => boolean;
